# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import subprocess

import cliapp


class Git(object):

    '''An interface to all git operations distix needs.'''

    def __init__(self, dirname):
        self._dirname = dirname

    def init(self):
        self._git(['init', '-q', self._dirname])

    def add_and_commit(self, filenames, commit_msg):
        self._git(['add'] + filenames, cwd=self._dirname)
        self._git(
            ['commit', '-q', '-m', commit_msg] + filenames,
            cwd=self._dirname)

    def find_dirt(self):
        output = self._git(
            ['status', '--short'], stdout=subprocess.PIPE, cwd=self._dirname)
        return output.splitlines()

    def _git(self, args, **kwargs):
        kwargs = dict(kwargs)
        if 'stdout' not in kwargs:
            kwargs['stdout'] = None
        if 'stderr' not in kwargs:
            kwargs['stderr'] = None
        return cliapp.runcmd(['git'] + args, **kwargs)
