# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import os
import uuid

import cliapp

import distixlib


class NewTicketPlugin(cliapp.Plugin):

    _commit_msg = 'new ticket'

    def enable(self):
        self.app.add_subcommand(
            'new', self.new_ticket, arg_synopsis='TITLE')

        self.app.settings.string(
            ['save-ticket-id'],
            'after creating the ticket, write its id to FILE',
            metavar='FILE')

    def new_ticket(self, args):
        '''Create a new ticket.'''

        title = args[0]

        repo = distixlib.Repository('.')
        repo.require_clean_working_tree()
        ticket_id = repo.invent_new_ticket_id()
        ticket = self._create_ticket(ticket_id, title)
        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)
        filenames = ticket_store.add_ticket(ticket)
        repo.commit_changes(filenames, self._commit_msg)
        self._show_ticket_id(ticket)

        if self.app.settings['save-ticket-id']:
            self._save_ticket_id(
                ticket_id, self.app.settings['save-ticket-id'])

    def _create_ticket(self, ticket_id, title):
        ticket = distixlib.Ticket()
        ticket.set_ticket_id(ticket_id)
        ticket.set_title(title)
        return ticket

    def _show_ticket_id(self, ticket):
        self.app.output.write(
            'New ticket: {ticket_id} {title}\n'.format(
                ticket_id=ticket.get_ticket_id(),
                title=ticket.get_title()))

    def _save_ticket_id(self, ticket_id, filename):
        with open(filename, 'w') as f:
            f.write(ticket_id)
