# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import os

import cliapp

import distixlib


class SetPlugin(cliapp.Plugin):

    _commit_msg = 'set key/value pair in ticket'

    def enable(self):
        self.app.add_subcommand(
            'set', self.set, arg_synopsis='KEY=VALUE TICKETID ...')

    def set(self, args):
        '''Set ticket metadata.'''

        key, value = self._parse_pair(args[0])
        ticket_ids = distixlib.get_ticket_ids(self.app.settings, args[1:])

        repo = distixlib.Repository('.')
        repo.require_clean_working_tree()

        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)

        for ticket_id in ticket_ids:
            ticket = ticket_store.get_ticket(ticket_id)
            ticket.add_metadata_key_value_pair(key, value)

        filenames = ticket_store.save_changes()
        repo.commit_changes(filenames, self._commit_msg)

    def _parse_pair(self, pair):
        return pair.split('=', 1)
