# Copyright 2014  Lars Wirzenius
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# =*= License: GPL-3+ =*=


import locale
import os
import uuid

import cliapp

import distixlib


class ShowTicketPlugin(cliapp.Plugin):

    def enable(self):
        self.app.add_subcommand(
            'show', self.show_ticket, arg_synopsis='TICKETID...')

    def show_ticket(self, args):
        '''Show existing tickets.'''

        ticket_ids = distixlib.get_ticket_ids(self.app.settings, args)
        for ticket_id in ticket_ids:
            ticket = self._load_ticket(ticket_id)
            self._show_ticket(ticket)

    def _load_ticket(self, ticket_id):
        repo = distixlib.Repository('.')
        ticket_store = repo.open_ticket_store(distixlib.tickets_dir_name)
        return ticket_store.get_ticket(ticket_id)

    def _show_ticket(self, ticket):
        _, encoding = locale.getdefaultlocale()
        if encoding is None:
            encoding = 'UTF8'

        thread = distixlib.MessageThread()
        for msg in ticket.get_messages():
            thread.add_message(msg)

        msg_renderer = distixlib.MessageRenderer()

        metadata = ticket.get_ticket_metadata()

        variables = {
            'ticket_id': ticket.get_ticket_id(),
            'metadata': metadata,
            'metadata_keys': sorted(metadata.keys()),
            'msgs': [
                msg_renderer.summary(msg)
                for msg in thread.get_messages_in_date_order()
            ],
        }

        renderer = distixlib.TextRenderer()
        renderer.set_output_encoding(encoding)

        text = renderer.render('show.j2', variables)
        self.app.output.write(text)
